#include "place.h"

Place::Place(QObject *parent) :
    QObject(parent)
{
}

Place::Place(const Place &other,QObject *parent) : QObject(parent)
{
    this->_id = QString(other._id);
    this->_name = QString(other._name);
    this->_address = QString(other._address);
}

Place::Place(const Place *other,QObject *parent) : QObject(parent)
{
    this->_id = QString(other->_id);
    this->_name = QString(other->_name);
    this->_address = QString(other->_address);
}


